==> kubernetes-model-flowcontrol-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitResponseFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LimitResponseFluent<A extends LimitResponseFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildQueuing instead.
   * @return The buildable object.
   */
  @Deprecated
  public QueuingConfiguration getQueuing();
  public QueuingConfiguration buildQueuing();
  public A withQueuing(QueuingConfiguration queuing);
  public Boolean hasQueuing();
  public A withNewQueuing(Integer handSize,Integer queueLengthLimit,Integer queues);
  public LimitResponseFluent.QueuingNested<A> withNewQueuing();
  public LimitResponseFluent.QueuingNested<A> withNewQueuingLike(QueuingConfiguration item);
  public LimitResponseFluent.QueuingNested<A> editQueuing();
  public LimitResponseFluent.QueuingNested<A> editOrNewQueuing();
  public LimitResponseFluent.QueuingNested<A> editOrNewQueuingLike(QueuingConfiguration item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface QueuingNested<N> extends Nested<N>,QueuingConfigurationFluent<LimitResponseFluent.QueuingNested<N>>{
    public N and();
    public N endQueuing();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitResponseFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LimitResponseFluent<A extends LimitResponseFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildQueuing instead.
   * @return The buildable object.
   */
  @Deprecated
  public QueuingConfiguration getQueuing();
  public QueuingConfiguration buildQueuing();
  public A withQueuing(QueuingConfiguration queuing);
  public Boolean hasQueuing();
  public A withNewQueuing(Integer handSize,Integer queueLengthLimit,Integer queues);
  public LimitResponseFluent.QueuingNested<A> withNewQueuing();
  public LimitResponseFluent.QueuingNested<A> withNewQueuingLike(QueuingConfiguration item);
  public LimitResponseFluent.QueuingNested<A> editQueuing();
  public LimitResponseFluent.QueuingNested<A> editOrNewQueuing();
  public LimitResponseFluent.QueuingNested<A> editOrNewQueuingLike(QueuingConfiguration item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface QueuingNested<N> extends Nested<N>,QueuingConfigurationFluent<LimitResponseFluent.QueuingNested<N>>{
    public N and();
    public N endQueuing();
    
  }
  
}
